package com.dgtly.common.utils;

import com.dgtly.common.utils.http.HttpUtils;
import net.sf.json.JSONArray;
import net.sf.json.JSONObject;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.UnsupportedEncodingException;
import java.net.URLEncoder;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * @author koucx
 * @version 1.0
 * @descption: 中文翻译英文工具类
 * @company 神州数码通用软件（洛阳）有限公司
 * @copyright (c) 2019 LuoYang DGT Co'Ltd Inc. All rights reserved.
 * @date 2020-03-24
 * @since JDK1.8
 */
public class TranslateUtil {

    private static final Logger log = LoggerFactory.getLogger(TranslateUtil.class);

    private static final String TRANSLATE_URL_OLD = "http://fanyi.youdao.com/translate";
    private static final String TRANSLATE_URL = "http://fanyi.youdao.com/openapi.do";

    private static final String regEx_script = "<script[^>]*?>[\\s\\S]*?<\\/script>"; // 定义script的正则表达式
    private static final String regEx_style = "<style[^>]*?>[\\s\\S]*?<\\/style>"; // 定义style的正则表达式
    private static final String regEx_html = "<[^>]+>"; // 定义HTML标签的正则表达式
    private static final String regEx_space = "\\s*|\t|\r|\n";//定义空格回车换行符


    /**
     * @param htmlStr
     * @return 删除Html标签
     */
    public static String delHTMLTag(String htmlStr) {
        Pattern p_script = Pattern.compile(regEx_script, Pattern.CASE_INSENSITIVE);
        Matcher m_script = p_script.matcher(htmlStr);
        htmlStr = m_script.replaceAll(""); // 过滤script标签

        Pattern p_style = Pattern.compile(regEx_style, Pattern.CASE_INSENSITIVE);
        Matcher m_style = p_style.matcher(htmlStr);
        htmlStr = m_style.replaceAll(""); // 过滤style标签

        Pattern p_html = Pattern.compile(regEx_html, Pattern.CASE_INSENSITIVE);
        Matcher m_html = p_html.matcher(htmlStr);
        List<String> matchStrs = new ArrayList<>();
        while (m_html.find()) { //此处find（）每次被调用后，会偏移到下一个匹配
            matchStrs.add(m_html.group());//获取当前匹配的值
        }

        for (int i = 0; i < matchStrs.size(); i++) {
            System.out.println(matchStrs.get(i));
        }

        htmlStr = m_html.replaceAll(""); // 过滤html标签

        Pattern p_space = Pattern.compile(regEx_space, Pattern.CASE_INSENSITIVE);
        Matcher m_space = p_space.matcher(htmlStr);
        htmlStr = m_space.replaceAll(""); // 过滤空格回车标签
        htmlStr = htmlStr.replaceAll("&nbsp;", "");
        htmlStr = htmlStr.replaceAll("↵", "");
        return htmlStr.trim(); // 返回文本字符串
    }

    /**
     * 处理含有html的翻译
     * @param html
     * @return
     */
    public static String getDesEnTranslateInfo(String html){

        Pattern p_html = Pattern.compile(regEx_html);
        String[] split = p_html.split(html);
        List<String> translates = new ArrayList();
        for (int i = 0; i <split.length ; i++) {
            String s =  split[i].replaceAll("&nbsp;","").trim();
            if(StringUtils.isNotEmpty(s)){
                translates.add(s);
            }
        }

        Collections.sort(translates,new MyComparator());

        for (int i = 0; i <translates.size() ; i++) {
            html = html.replace(translates.get(i),getEnTranslateInfo(translates.get(i)));
        }
        return html;
    }


    /**
     * @Description: 调用有道翻译接口中文翻译成英文
     * @Param: [msg]
     * @Return: java.lang.String
     * @Author: koucx
     * @Date: 2020-03-24
    **/
    public static String getEnTranslateInfo(String msg){
        String params = "doctype=json&type=ZH_CN2EN&i="+msg;
        try{
            String enInfo = HttpUtils.sendGet(TRANSLATE_URL_OLD, params);
            /**
             * {
             *     "type": "ZH_CN2EN",
             *     "errorCode": 0,
             *     "elapsedTime": 1,
             *     "translateResult": [
             *         [
             *             {
             *                 "src": "计算",//需要翻译的中文
             *                 "tgt": "To calculate"//翻译后的中文
             *             }
             *         ]
             *     ]
             * }
             *
             * 根据以上json串获取相应英文翻译
             *
             */
            if(StringUtils.isNotEmpty(enInfo)){
                JSONObject object = JSONObject.fromObject(enInfo);
                if(object!=null){
                    JSONArray array = object.getJSONArray("translateResult");
                    if(array!=null && array.size()>0){
                        String tgt = "";
                        for (Object obj:array) {
                            JSONArray arr = JSONArray.fromObject(obj);
                            for (Object o:arr) {
                                JSONObject json = JSONObject.fromObject(o);
                                if(json!=null && json.containsKey("tgt")){
                                        tgt +=" "+json.getString("tgt");
                                }
                            }
                        }
                        return tgt;
                    }
                }
            }
        }catch (Exception e){
            log.info("翻译出错");
        }
        return "";
    }

    /**
     * @Description: 调用有道翻译接口中文翻译成英文
     * @Param: [msg]
     * @Verision:2.0
     * @Return: java.lang.String
     * @Author: koucx
     * @Date: 2020-03-24
     **/
    public static String getEnTranslateInfoOld(String msg){

        try{
            if(StringUtils.isNotEmpty(msg)){
                String params = "keyfrom=pdblog&key=993123434&type=data&doctype=json&version=1.1&q="+ URLEncoder.encode(msg,"utf-8");
                String enInfo = HttpUtils.sendGet(TRANSLATE_URL, params);
                JSONObject jsonObject = JSONObject.fromObject(enInfo);
                if(jsonObject!=null){
                    Object obj = jsonObject.get("translation");
                    JSONArray jsonArray = JSONArray.fromObject(obj);
                    if(jsonArray!=null && jsonArray.size()>0){
                        return jsonArray.get(0)==null?"":jsonArray.get(0).toString();
                    }
                }
            }
        }catch (Exception e){
            log.info("翻译出错");
        }
        return "";
    }


    public static void main(String[] args) {
        String htmlStr = "<p>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<span style=\"color: rgb(62, 62, 62); font-family: 微软雅黑, &quot;Microsoft YaHei&quot;; font-size: 16px;\">铁皮</span><a href=\"http://www.kefeiyajiaju.com/wenjiangui/\" target=\"_self\" style=\"margin: 0px; padding: 0px; background-color: rgb(255, 255, 255); color: rgb(10, 10, 10); max-width: 100%; font-family: 微软雅黑, &quot;Microsoft YaHei&quot;; font-size: 16px;\">文件柜</a><span style=\"color: rgb(62, 62, 62); font-family: 微软雅黑, &quot;Microsoft YaHei&quot;; font-size: 16px;\">已经成为办公环境中，不可缺少的一部分。市场上有很多品牌的铁皮柜，鱼龙混杂，让大家分不清好坏 ，也弄不清楚铁皮柜多厚用着比较合适。</span></p><p>&nbsp; &nbsp; &nbsp; &nbsp;&nbsp;<span style=\"font-family: 微软雅黑, &quot;Microsoft YaHei&quot;; font-size: 16px; color: rgb(62, 62, 62);\">尺寸：铁皮柜的标准尺寸高度一般为1850-2000之间，深度一般在360mm-430mm，科飞亚铁皮柜标准尺寸为H1850mm*W900mm*D390mm，这个尺寸是经过多次试验之后制定的。1850的高度内置4层隔板分隔5层，A4档案盒可以直立存取深度也是存取最为舒适的一个深度，既不会显得文件拥挤又不会因太深而浪费空间。</span></p><p style=\"margin-top: 15px; margin-bottom: 15px; padding: 0px; max-width: 100%; color: rgb(62, 62, 62); font-family: 微软雅黑; font-size: 18px;\"><span style=\"margin: 0px; padding: 0px; max-width: 100%; font-family: 微软雅黑, &quot;Microsoft YaHei&quot;; font-size: 16px;\">&nbsp; &nbsp; &nbsp; &nbsp;板材厚度：铁皮柜厚度直接决定铁皮柜的使用寿命。一般优质铁皮柜钢板厚度都在0.6-0.8mm之间，而一些便宜的柜子钢板厚度只有0.3-0.5mm。需要注意的是，这个厚度是裸板厚度，购买铁皮柜的时候一定要问清楚是裸板厚度还是喷涂后的厚度。</span></p><p style=\"margin-top: 15px; margin-bottom: 15px; padding: 0px; max-width: 100%; color: rgb(62, 62, 62); font-family: 微软雅黑; font-size: 18px;\"><span style=\"margin: 0px; padding: 0px; max-width: 100%; font-family: 微软雅黑, &quot;Microsoft YaHei&quot;; font-size: 16px;\">&nbsp; &nbsp; &nbsp; &nbsp;款式：铁皮柜款式多样，具体要根据实际使用场所和需求进行选择。如果不清楚哪款最合适，可以向商家说明自己的使用需求，可以推荐一款最合适的柜子。</span></p><p><br></p>";
        /*String zhStr = "尺寸：铁皮柜的标准尺寸高度一般为1850-2000之间，深度一般在360mm-430mm，科飞亚铁皮柜标准尺寸为H1850mm*W900mm*D390mm，这个尺寸是经过多次试验之后制定的。1850的高度内置4层隔板分隔5层，A4档案盒可以直立存取深度也是存取最为舒适的一个深度，既不会显得文件拥挤又不会因太深而浪费空间。";
        htmlStr = htmlStr.replace(zhStr,"");*/
        htmlStr = htmlStr.replaceAll("&nbsp;","").trim();
        Pattern p_html = Pattern.compile(regEx_html);
        String[] split = p_html.split(htmlStr);
        List<String> translates = new ArrayList();
        for (int i = 0; i <split.length ; i++) {
           String s =  split[i].replaceAll("&nbsp;","").trim();
            if(StringUtils.isNotEmpty(s)){
                translates.add(s);
            }
        }

        Collections.sort(translates,new MyComparator());


        for (int i = 0; i <translates.size() ; i++) {
            htmlStr = htmlStr.replace(translates.get(i),getEnTranslateInfo(translates.get(i)));
        }
        System.out.println(htmlStr);
    }

}

class MyComparator implements Comparator<String> {


    @Override
    public int compare(String o1, String o2) {
        return o2.length()-o1.length();
    }
}
