package com.dgtly.system.mapper;

import com.dgtly.common.annotation.SwitchEn;
import com.dgtly.system.domain.SysCompany;
import java.util.List;

/**
 * 公司表Mapper接口
 * 
 * @author dgtly
 * @date 2020-01-08
 */
public interface SysCompanyMapper 
{
    /**
     * 查询公司表
     * 
     * @param id 公司表ID
     * @return 公司表
     */
    @SwitchEn(oldfiles = {"sc.company_name","sc.legal_person","sc.company_introduce","sc.primary_business","sc.detail_address"},
            newfiles = {"sc.company_name_en company_name","sc.legal_person_en legal_person","sc.company_introduce_en company_introduce","sc.primary_business_en primary_business","sc.detail_address_en detail_address"})
    public SysCompany selectSysCompanyById(Long id);

    /**
     * 查询公司表列表
     * 
     * @param sysCompany 公司表
     * @return 公司表集合
     */
    public List<SysCompany> selectSysCompanyList(SysCompany sysCompany);

    /**
     * 新增公司表
     * 
     * @param sysCompany 公司表
     * @return 结果
     */
    public int insertSysCompany(SysCompany sysCompany);

    /**
     * 修改公司表
     * 
     * @param sysCompany 公司表
     * @return 结果
     */
    public int updateSysCompany(SysCompany sysCompany);

    /**
     * 删除公司表
     * 
     * @param id 公司表ID
     * @return 结果
     */
    public int deleteSysCompanyById(Long id);

    /**
     * 批量删除公司表
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteSysCompanyByIds(String[] ids);
    /**
     * 查询热门商家列表
     * @param
     * @return
     */
    @SwitchEn(oldfiles = {"sc.company_name","sc.primary_business"},
            newfiles = {"sc.company_name_en company_name","sc.primary_business_en primary_business"})
    public List<SysCompany> selectCompanyHotList();

    /**
     * 查询公司表排除根目录公司
     * @param:
     * @return:
     * @auther: qxp
     * @date: 2020-2-25
     */
    @SwitchEn(oldfiles = {"sc.company_name","sc.legal_person","sc.company_introduce","sc.primary_business","sc.detail_address"},
            newfiles = {"sc.company_name_en company_name","sc.legal_person_en legal_person","sc.company_introduce_en company_introduce","sc.primary_business_en primary_business","sc.detail_address_en detail_address"})
    List<SysCompany> selectSysCompanyListExRoot(SysCompany sysCompany);



    public int countCompany();
}
