package com.dgtly.system.mapper;

import java.util.List;

import com.dgtly.common.annotation.SwitchEn;
import com.dgtly.system.domain.SysNotice;

/**
 * 公告 数据层
 * 
 * @author ruoyi
 */
public interface SysNoticeMapper
{
    /**
     * 查询公告信息
     * 
     * @param noticeId 公告ID
     * @return 公告信息
     */
    @SwitchEn(oldfiles = {
            "notice_title",
            "notice_outline",
            "notice_content"
    },newfiles = {
            "notice_title_en notice_title",
            "notice_outline_en notice_outline",
            "notice_content_en notice_content"
    })
    public SysNotice selectNoticeById(Long noticeId);

    /**
     * 查询公告列表
     * 
     * @param notice 公告信息
     * @return 公告集合
     */
    @SwitchEn(oldfiles = {
            "notice_title",
            "notice_outline",
            "notice_content"
    },newfiles = {
            "notice_title_en notice_title",
            "notice_outline_en notice_outline",
            "notice_content_en notice_content"
    })
    public List<SysNotice> selectNoticeList(SysNotice notice);

    /**
     * 查询公告列表根据数据权限
     *
     * @param notice 公告信息
     * @return 公告集合
     */
    @SwitchEn(oldfiles = {
            "sn.notice_title",
            "sn.notice_outline",
            "sn.notice_content"
    },newfiles = {
            "sn.notice_title_en notice_title",
            "sn.notice_outline_en notice_outline",
            "sn.notice_content_en notice_content"
    })
    public List<SysNotice> selectNoticeListByRole(SysNotice notice);



    /**
     * @descption: 根据类型返回内容列表前三个
     * @param:类型
     * @return: 内容列表
     * @auther: LiuLingChao
     * @date: 2019-11-04 11:36
     */
    @SwitchEn(oldfiles = {
            "notice_title",
            "notice_outline",
            "notice_content"
    },newfiles = {
            "notice_title_en notice_title",
            "notice_outline_en notice_outline",
            "notice_content_en notice_content"
    })
    public List<SysNotice> selectNoticeTop3ByRole(SysNotice notice);

    /**
     * 新增公告
     * 
     * @param notice 公告信息
     * @return 结果
     */
    public int insertNotice(SysNotice notice);

    /**
     * 修改公告
     * 
     * @param notice 公告信息
     * @return 结果
     */
    public int updateNotice(SysNotice notice);

    /**
     * 批量删除公告
     * 
     * @param noticeIds 需要删除的数据ID
     * @return 结果
     */
    public int deleteNoticeByIds(String[] noticeIds);
}